@@ -23,7 +23,7 @@ from eva.binder.binder_utils import (
 )
 from eva.binder.statement_binder_context import StatementBinderContext
 from eva.catalog.catalog_manager import CatalogManager
-from eva.catalog.catalog_type import ColumnType, NdArrayType, TableType
+from eva.catalog.catalog_type import IndexType, NdArrayType, TableType
 from eva.expression.abstract_expression import AbstractExpression
 from eva.expression.function_expression import FunctionExpression
 from eva.expression.tuple_value_expression import TupleValueExpression
@@ -80,6 +80,8 @@ class StatementBinder:
     @bind.register(CreateIndexStatement)
     def _bind_create_index_statement(self, node: CreateIndexStatement):
         self.bind(node.table_ref)
+        if node.udf_func:
+            self.bind(node.udf_func)
 
         # TODO: create index currently only supports single numpy column.
         assert len(node.col_list) == 1, "Index cannot be created on more than 1 column"
@@ -87,11 +89,31 @@ class StatementBinder:
         # TODO: create index currently only works on TableInfo, but will extend later.
         assert node.table_ref.is_table_atom(), "Index can only be created on Tableinfo"
 
-        col_def = node.col_list[0]
-        table_ref_obj = node.table_ref.table.table_obj
-        col = [col for col in table_ref_obj.columns if col.name == col_def.name][0]
-        assert col.type == ColumnType.NDARRAY, "Index input needs to be numpy array"
-        assert col.array_type == NdArrayType.FLOAT32, "Index input needs to be float32"
+        if IndexType.is_faiss_index_type(node.index_type):
+            if not node.udf_func:
+                # Feature table type needs to be float32 numpy array.
+                col_def = node.col_list[0]
+                table_ref_obj = node.table_ref.table.table_obj
+                col = [
+                    col for col in table_ref_obj.columns if col.name == col_def.name
+                ][0]
+                if not col.array_type == NdArrayType.FLOAT32:
+                    raise BinderError("Index input needs to be float32.")
+                if not len(col.array_dimensions) == 2:
+                    raise BinderError("Index input needs to be 2 dimensional.")
+            else:
+                # Output of the UDF should be 2 dimension and float32 type.
+                catalog_manager = CatalogManager()
+                udf_obj = catalog_manager.get_udf_catalog_entry_by_name(
+                    node.udf_func.name
+                )
+                for output in udf_obj.outputs:
+                    if not output.array_type == NdArrayType.FLOAT32:
+                        raise BinderError("Index input needs to be float32.")
+                    if not len(output.array_dimensions) == 2:
+                        raise BinderError("Index input needs to be 2 dimensional.")
+        else:
+            raise BinderError("Index type {} is not supported.".format(node.index_type))
 
     @bind.register(SelectStatement)
     def _bind_select_statement(self, node: SelectStatement):
@@ -161,14 +183,13 @@ class StatementBinder:
             self.bind(func_expr)
             output_cols = []
             for obj, alias in zip(func_expr.output_objs, func_expr.alias.col_names):
-                alias_obj = self._catalog.udf_io(
-                    alias,
-                    data_type=obj.type,
-                    array_type=obj.array_type,
-                    dimensions=obj.array_dimensions,
-                    is_input=obj.is_input,
+                col_alias = "{}.{}".format(func_expr.alias.alias_name, alias)
+                alias_obj = TupleValueExpression(
+                    col_name=alias,
+                    table_alias=func_expr.alias.alias_name,
+                    col_object=obj,
+                    col_alias=col_alias,
                 )
-
                 output_cols.append(alias_obj)
             self._binder_context.add_derived_table_alias(
                 func_expr.alias.alias_name, output_cols
@@ -190,7 +211,7 @@ class StatementBinder:
         for child in node.children:
             self.bind(child)
 
-        udf_obj = self._catalog.get_udf_by_name(node.name)
+        udf_obj = self._catalog.get_udf_catalog_entry_by_name(node.name)
         if udf_obj is None:
             err_msg = (
                 f"UDF with name {node.name} does not exist in the catalog. "
@@ -209,7 +230,8 @@ class StatementBinder:
             logger.error(err_msg)
             raise BinderError(err_msg)
 
-        output_objs = self._catalog.get_udf_outputs(udf_obj)
+        node.udf_obj = udf_obj
+        output_objs = self._catalog.get_udf_io_catalog_output_entries(udf_obj)
         if node.output:
             for obj in output_objs:
                 if obj.name.lower() == node.output:
