@@ -17,13 +17,13 @@ from typing import Dict, List
 from sqlalchemy import TEXT, Column, Float, Integer, LargeBinary
 
 from eva.catalog.catalog_type import ColumnType
-from eva.catalog.models.df_column import DataFrameColumn
+from eva.catalog.models.column_catalog import ColumnCatalogEntry
 from eva.utils.logging_manager import logger
 
 
 class SchemaUtils(object):
     @staticmethod
-    def xform_to_sqlalchemy_column(df_column: DataFrameColumn) -> Column:
+    def xform_to_sqlalchemy_column(df_column: ColumnCatalogEntry) -> Column:
         column_type = df_column.type
 
         sqlalchemy_column = None
@@ -42,12 +42,12 @@ class SchemaUtils(object):
 
     @staticmethod
     def xform_to_sqlalchemy_schema(
-        column_list: List[DataFrameColumn],
+        column_list: List[ColumnCatalogEntry],
     ) -> Dict[str, Column]:
         """Converts the list of DataFrameColumns to SQLAlchemyColumns
 
         Args:
-            column_list (List[DataFrameColumn]): columns to be converted
+            column_list (List[ColumnCatalog]): columns to be converted
 
         Returns:
             Dict[str, Column]: mapping from column_name to sqlalchemy column object
