@@ -27,8 +27,6 @@ class SQLConfig:
         _instance: stores the singleton instance of the class.
     """
 
-    _instance = None
-
     def __new__(cls):
         """Overrides the default __new__ method.
 
@@ -38,7 +36,7 @@ class SQLConfig:
         Returns:
             An instance of the class.
         """
-        if cls._instance is None:
+        if not hasattr(cls, "_instance"):
             cls._instance = super(SQLConfig, cls).__new__(cls)
         return cls._instance
 
