@@ -25,11 +25,10 @@ from eva.configuration.constants import (
 
 
 class ConfigurationManager(object):
-    _instance = None
     _yml_path = EVA_DEFAULT_DIR / EVA_CONFIG_FILE
 
     def __new__(cls):
-        if cls._instance is None:
+        if not hasattr(cls, "_instance"):
             cls._instance = super(ConfigurationManager, cls).__new__(cls)
             cls._create_if_not_exists()
 
