@@ -15,13 +15,20 @@
 from pathlib import Path
 
 import eva
+from eva.version import VERSION
 
 EVA_INSTALLATION_DIR = Path(eva.__file__).parent
-EVA_DEFAULT_DIR = Path.home() / ".eva"
+EVA_ROOT_DIR = Path(eva.__file__).parent.parent
+# Using eva version to govern the EVA_DEFAULT_DIR
+# This means we won't support backward compatibility as each version will maintain its own copy of database.
+# Ideally, if the new release is not breaking backward compatibilty, we can keep using the same copy.
+# We can revisit it later
+EVA_DEFAULT_DIR = Path.home() / ".eva" / str(VERSION)
 EVA_DATASET_DIR = "eva_datasets"
 EVA_UPLOAD_DIR = "tmp"
 EVA_CONFIG_FILE = "eva.yml"
 UDF_DIR = "udfs"
 CATALOG_DIR = "catalog"
+INDEX_DIR = "index"
 DATASET_DATAFRAME_NAME = "dataset"
 DB_DEFAULT_URI = "sqlite:///{}/eva_catalog.db".format(EVA_DEFAULT_DIR.resolve())
