@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 from eva.executor.abstract_executor import AbstractExecutor
-from eva.planner.insert_plan import InsertPlan
+from eva.plan_nodes.insert_plan import InsertPlan
 
 
 class InsertExecutor(AbstractExecutor):
