@@ -15,9 +15,10 @@
 from typing import Generator, Iterator
 
 from eva.executor.abstract_executor import AbstractExecutor
-from eva.executor.executor_utils import apply_predicate, apply_project
+from eva.executor.executor_utils import ExecutorError, apply_predicate, apply_project
 from eva.models.storage.batch import Batch
 from eva.plan_nodes.lateral_join_plan import LateralJoinPlan
+from eva.utils.logging_manager import logger
 
 
 class LateralJoinExecutor(AbstractExecutor):
@@ -32,14 +33,18 @@ class LateralJoinExecutor(AbstractExecutor):
     def exec(self, *args, **kwargs) -> Iterator[Batch]:
         outer = self.children[0]
         inner = self.children[1]
-        for outer_batch in outer.exec(**kwargs):
-            for result_batch in inner.exec(lateral_input=outer_batch):
-                result_batch = Batch.join(outer_batch, result_batch)
-                result_batch.reset_index()
-                result_batch = apply_predicate(result_batch, self.predicate)
-                result_batch = apply_project(result_batch, self.join_project)
-                if not result_batch.empty():
-                    yield result_batch
+        try:
+            for outer_batch in outer.exec(**kwargs):
+                for result_batch in inner.exec(lateral_input=outer_batch):
+                    result_batch = Batch.join(outer_batch, result_batch)
+                    result_batch.reset_index()
+                    result_batch = apply_predicate(result_batch, self.predicate)
+                    result_batch = apply_project(result_batch, self.join_project)
+                    if not result_batch.empty():
+                        yield result_batch
+        except Exception as e:
+            logger.error(e)
+            raise ExecutorError(e)
 
     def __call__(self, *args, **kwargs) -> Generator[Batch, None, None]:
         yield from self.exec(*args, **kwargs)
