@@ -40,7 +40,7 @@ class LoadCSVExecutor(AbstractExecutor):
 
     def exec(self):
         """
-        Read the input meta file using pandas and persist data
+        Read the input csv file using pandas and persist data
         using storage engine
         """
 
@@ -48,7 +48,10 @@ class LoadCSVExecutor(AbstractExecutor):
         table_info = self.node.table_info
         database_name = table_info.database_name
         table_name = table_info.table_name
-        table_obj = self.catalog.get_dataset_metadata(database_name, table_name)
+        table_obj = self.catalog.get_table_catalog_entry(
+            table_name,
+            database_name,
+        )
         if table_obj is None:
             error = f"{table_name} does not exist."
             logger.error(error)
