@@ -15,13 +15,16 @@
 from typing import Iterator
 
 from eva.executor.abstract_executor import AbstractExecutor
+from eva.executor.apply_and_merge_executor import ApplyAndMergeExecutor
 from eva.executor.create_executor import CreateExecutor
 from eva.executor.create_index_executor import CreateIndexExecutor
 from eva.executor.create_mat_view_executor import CreateMaterializedViewExecutor
 from eva.executor.create_udf_executor import CreateUDFExecutor
 from eva.executor.drop_executor import DropExecutor
 from eva.executor.drop_udf_executor import DropUDFExecutor
+from eva.executor.executor_utils import ExecutorError
 from eva.executor.explain_executor import ExplainExecutor
+from eva.executor.faiss_index_scan_executor import FaissIndexScanExecutor
 from eva.executor.function_scan_executor import FunctionScanExecutor
 from eva.executor.groupby_executor import GroupByExecutor
 from eva.executor.hash_join_executor import HashJoinExecutor
@@ -45,6 +48,7 @@ from eva.experimental.ray.executor.exchange_executor import ExchangeExecutor
 from eva.models.storage.batch import Batch
 from eva.plan_nodes.abstract_plan import AbstractPlan
 from eva.plan_nodes.types import PlanOprType
+from eva.utils.logging_manager import logger
 
 
 class PlanExecutor:
@@ -130,7 +134,10 @@ class PlanExecutor:
             executor_node = ExplainExecutor(node=plan)
         elif plan_opr_type == PlanOprType.CREATE_INDEX:
             executor_node = CreateIndexExecutor(node=plan)
-
+        elif plan_opr_type == PlanOprType.APPLY_AND_MERGE:
+            executor_node = ApplyAndMergeExecutor(node=plan)
+        elif plan_opr_type == PlanOprType.FAISS_INDEX_SCAN:
+            executor_node = FaissIndexScanExecutor(node=plan)
         # EXPLAIN does not need to build execution tree for its children
         if plan_opr_type != PlanOprType.EXPLAIN:
             # Build Executor Tree for children
@@ -150,8 +157,12 @@ class PlanExecutor:
 
     def execute_plan(self) -> Iterator[Batch]:
         """execute the plan tree"""
-        execution_tree = self._build_execution_tree(self._plan)
-        output = execution_tree.exec()
-        if output is not None:
-            yield from output
-        self._clean_execution_tree(execution_tree)
+        try:
+            execution_tree = self._build_execution_tree(self._plan)
+            output = execution_tree.exec()
+            if output is not None:
+                yield from output
+            self._clean_execution_tree(execution_tree)
+        except Exception as e:
+            logger.error(str(e))
+            raise ExecutorError(e)
