@@ -20,6 +20,7 @@ from eva.executor.executor_utils import ExecutorError
 from eva.models.storage.batch import Batch
 from eva.plan_nodes.storage_plan import StoragePlan
 from eva.storage.storage_engine import StorageEngine
+from eva.utils.logging_manager import logger
 
 
 class StorageExecutor(AbstractExecutor):
@@ -30,23 +31,27 @@ class StorageExecutor(AbstractExecutor):
         pass
 
     def exec(self) -> Iterator[Batch]:
-        storage_engine = StorageEngine.factory(self.node.table)
+        try:
+            storage_engine = StorageEngine.factory(self.node.table)
 
-        if self.node.table.table_type == TableType.VIDEO_DATA:
-            return storage_engine.read(
-                self.node.table,
-                self.node.batch_mem_size,
-                predicate=self.node.predicate,
-                sampling_rate=self.node.sampling_rate,
-            )
-        elif self.node.table.table_type == TableType.IMAGE_DATA:
-            return storage_engine.read(self.node.table)
-        elif self.node.table.table_type == TableType.STRUCTURED_DATA:
-            return storage_engine.read(self.node.table, self.node.batch_mem_size)
-        else:
-            raise ExecutorError(
-                f"Unsupported TableType  {self.node.table.table_type} encountered"
-            )
+            if self.node.table.table_type == TableType.VIDEO_DATA:
+                return storage_engine.read(
+                    self.node.table,
+                    self.node.batch_mem_size,
+                    predicate=self.node.predicate,
+                    sampling_rate=self.node.sampling_rate,
+                )
+            elif self.node.table.table_type == TableType.IMAGE_DATA:
+                return storage_engine.read(self.node.table)
+            elif self.node.table.table_type == TableType.STRUCTURED_DATA:
+                return storage_engine.read(self.node.table, self.node.batch_mem_size)
+            else:
+                raise ExecutorError(
+                    f"Unsupported TableType  {self.node.table.table_type} encountered"
+                )
+        except Exception as e:
+            logger.error(e)
+            raise ExecutorError(e)
 
     def __call__(self, **kwargs) -> Generator[Batch, None, None]:
         yield from self.exec()
