@@ -278,7 +278,9 @@ class Batch:
         if not len(batches):
             return Batch()
         frames = [batch.frames for batch in batches]
-        new_frames = pd.concat(frames, axis=1, copy=False)
+        new_frames = pd.concat(frames, axis=1, copy=False, ignore_index=False).fillna(
+            method="ffill"
+        )
         if new_frames.columns.duplicated().any():
             logger.warn("Duplicated column name detected {}".format(new_frames))
         return Batch(new_frames)
@@ -427,9 +429,9 @@ class Batch:
             ]
         else:
             for col_name in self.columns:
-                if "." in col_name:
+                if "." in str(col_name):
                     new_col_names.append(
-                        "{}.{}".format(alias.alias_name, col_name.split(".")[1])
+                        "{}.{}".format(alias.alias_name, str(col_name).split(".")[1])
                     )
                 else:
                     new_col_names.append("{}.{}".format(alias.alias_name, col_name))
@@ -446,3 +448,7 @@ class Batch:
                 new_col_names.append(col_name)
 
         self._frames.columns = new_col_names
+
+    def rename(self, columns) -> None:
+        "Rename column names"
+        self._frames.rename(columns=columns, inplace=True)
