@@ -17,11 +17,12 @@ from pathlib import Path
 from typing import List
 
 from eva.catalog.catalog_type import IndexType
-from eva.catalog.models.df_column import DataFrameColumn
-from eva.catalog.models.df_metadata import DataFrameMetadata
-from eva.catalog.models.udf_io import UdfIO
+from eva.catalog.models.column_catalog import ColumnCatalogEntry
+from eva.catalog.models.table_catalog import TableCatalogEntry
+from eva.catalog.models.udf_io_catalog import UdfIOCatalogEntry
 from eva.expression.abstract_expression import AbstractExpression
 from eva.expression.constant_value_expression import ConstantValueExpression
+from eva.expression.function_expression import FunctionExpression
 from eva.parser.alias import Alias
 from eva.parser.create_statement import ColumnDefinition
 from eva.parser.table_ref import TableInfo, TableRef
@@ -58,6 +59,8 @@ class OperatorType(IntEnum):
     LOGICALDROPUDF = auto()
     LOGICALEXPLAIN = auto()
     LOGICALCREATEINDEX = auto()
+    LOGICAL_APPLY_AND_MERGE = auto()
+    LOGICALFAISSINDEXSCAN = auto()
     LOGICALDELIMITER = auto()
 
 
@@ -131,9 +134,10 @@ class Dummy(Operator):
     It track the group_id of the matching operator.
     """
 
-    def __init__(self, group_id: int):
+    def __init__(self, group_id: int, opr: Operator):
         super().__init__(OperatorType.DUMMY, None)
         self.group_id = group_id
+        self.opr = opr
 
     def __hash__(self) -> int:
         return hash((super().__hash__(), self.group_id))
@@ -143,7 +147,7 @@ class LogicalGet(Operator):
     def __init__(
         self,
         video: TableRef,
-        dataset_metadata: DataFrameMetadata,
+        table_obj: TableCatalogEntry,
         alias: str,
         predicate: AbstractExpression = None,
         target_list: List[AbstractExpression] = None,
@@ -151,7 +155,7 @@ class LogicalGet(Operator):
         children=None,
     ):
         self._video = video
-        self._dataset_metadata = dataset_metadata
+        self._table_obj = table_obj
         self._alias = alias
         self._predicate = predicate
         self._target_list = target_list
@@ -163,8 +167,8 @@ class LogicalGet(Operator):
         return self._video
 
     @property
-    def dataset_metadata(self):
-        return self._dataset_metadata
+    def table_obj(self):
+        return self._table_obj
 
     @property
     def alias(self):
@@ -197,7 +201,7 @@ class LogicalGet(Operator):
         return (
             is_subtree_equal
             and self.video == other.video
-            and self.dataset_metadata == other.dataset_metadata
+            and self.table_obj == other.table_obj
             and self.alias == other.alias
             and self.predicate == other.predicate
             and self.target_list == other.target_list
@@ -210,7 +214,7 @@ class LogicalGet(Operator):
                 super().__hash__(),
                 self.alias,
                 self.video,
-                self.dataset_metadata,
+                self.table_obj,
                 self.predicate,
                 tuple(self.target_list or []),
                 self.sampling_rate,
@@ -394,7 +398,7 @@ class LogicalInsert(Operator):
     """[Logical Node for Insert operation]
 
     Arguments:
-        table_metainfo(DataFrameMetadata): table to intert data into
+        table(TableCatalogEntry): table to intert data into
         column_list{List[AbstractExpression]}:
             [After binding annotated column_list]
         value_list{List[AbstractExpression]}:
@@ -403,19 +407,19 @@ class LogicalInsert(Operator):
 
     def __init__(
         self,
-        table_metainfo: DataFrameMetadata,
+        table: TableCatalogEntry,
         column_list: List[AbstractExpression],
         value_list: List[AbstractExpression],
         children: List = None,
     ):
         super().__init__(OperatorType.LOGICALINSERT, children)
-        self._table_metainfo = table_metainfo
+        self._table = table
         self._column_list = column_list
         self._value_list = value_list
 
     @property
-    def table_metainfo(self):
-        return self._table_metainfo
+    def table(self):
+        return self._table
 
     @property
     def value_list(self):
@@ -431,7 +435,7 @@ class LogicalInsert(Operator):
             return False
         return (
             is_subtree_equal
-            and self.table_metainfo == other.table_metainfo
+            and self.table == other.table
             and self.value_list == other.value_list
             and self.column_list == other.column_list
         )
@@ -440,7 +444,7 @@ class LogicalInsert(Operator):
         return hash(
             (
                 super().__hash__(),
-                self.table_metainfo,
+                self.table,
                 tuple(self.value_list),
                 tuple(self.column_list),
             )
@@ -580,9 +584,9 @@ class LogicalCreateUDF(Operator):
         if_not_exists: bool
             if true should throw an error if udf with same name exists
             else will replace the existing
-        inputs: List[UdfIO]
+        inputs: List[UdfIOCatalogEntry]
             udf inputs, annotated list similar to table columns
-        outputs: List[UdfIO]
+        outputs: List[UdfIOCatalogEntry]
             udf outputs, annotated list similar to table columns
         impl_path: Path
             file path which holds the implementation of the udf.
@@ -596,8 +600,8 @@ class LogicalCreateUDF(Operator):
         self,
         name: str,
         if_not_exists: bool,
-        inputs: List[UdfIO],
-        outputs: List[UdfIO],
+        inputs: List[UdfIOCatalogEntry],
+        outputs: List[UdfIOCatalogEntry],
         impl_path: Path,
         udf_type: str = None,
         children: List = None,
@@ -705,7 +709,7 @@ class LogicalLoadData(Operator):
     """Logical node for load data operation
 
     Arguments:
-        table_metainfo(DataFrameMetadata): table to load data into
+        table(TableCatalogEntry): table to load data into
         path(Path): file path from where we are loading data
     """
 
@@ -822,7 +826,7 @@ class LogicalUpload(Operator):
                 column_list: {}, \
                 file_options: {})".format(
             self.path,
-            "string of video blob",
+            "video blob",
             self.table_info,
             self.column_list,
             self.file_options,
@@ -899,7 +903,7 @@ class LogicalFunctionScan(Operator):
         )
 
     def __hash__(self) -> int:
-        return hash((super().__hash__(), self.func_expr))
+        return hash((super().__hash__(), self.func_expr, self.do_unnest, self.alias))
 
 
 class LogicalJoin(Operator):
@@ -917,8 +921,8 @@ class LogicalJoin(Operator):
         self,
         join_type: JoinType,
         join_predicate: AbstractExpression = None,
-        left_keys: List[DataFrameColumn] = None,
-        right_keys: List[DataFrameColumn] = None,
+        left_keys: List[ColumnCatalogEntry] = None,
+        right_keys: List[ColumnCatalogEntry] = None,
         children: List = None,
     ):
         super().__init__(OperatorType.LOGICALJOIN, children)
@@ -926,7 +930,7 @@ class LogicalJoin(Operator):
         self._join_predicate = join_predicate
         self._left_keys = left_keys
         self._right_keys = right_keys
-        self._join_project = []
+        self._join_project = None
 
     @property
     def join_type(self):
@@ -936,34 +940,18 @@ class LogicalJoin(Operator):
     def join_predicate(self):
         return self._join_predicate
 
-    @join_predicate.setter
-    def join_predicate(self, predicate):
-        self._join_predicate = predicate
-
     @property
     def left_keys(self):
         return self._left_keys
 
-    @left_keys.setter
-    def left_keys(self, keys):
-        self._left_key = keys
-
     @property
     def right_keys(self):
         return self._right_keys
 
-    @right_keys.setter
-    def right_keys(self, keys):
-        self._right_keys = keys
-
     @property
     def join_project(self):
         return self._join_project
 
-    @join_project.setter
-    def join_project(self, join_project):
-        self._target_list = join_project
-
     def lhs(self):
         return self.children[0]
 
@@ -991,7 +979,7 @@ class LogicalJoin(Operator):
                 self.join_predicate,
                 self.left_keys,
                 self.right_keys,
-                tuple(self.join_project),
+                tuple(self.join_project or []),
             )
         )
 
@@ -1109,6 +1097,7 @@ class LogicalCreateIndex(Operator):
         table_ref: TableRef,
         col_list: List[ColumnDefinition],
         index_type: IndexType,
+        udf_func: FunctionExpression = None,
         children: List = None,
     ):
         super().__init__(OperatorType.LOGICALCREATEINDEX, children)
@@ -1116,6 +1105,7 @@ class LogicalCreateIndex(Operator):
         self._table_ref = table_ref
         self._col_list = col_list
         self._index_type = index_type
+        self._udf_func = udf_func
 
     @property
     def name(self):
@@ -1133,6 +1123,10 @@ class LogicalCreateIndex(Operator):
     def index_type(self):
         return self._index_type
 
+    @property
+    def udf_func(self):
+        return self._udf_func
+
     def __eq__(self, other):
         is_subtree_equal = super().__eq__(other)
         if not isinstance(other, LogicalCreateIndex):
@@ -1143,6 +1137,7 @@ class LogicalCreateIndex(Operator):
             and self.table_ref == other.table_ref
             and self.col_list == other.col_list
             and self.index_type == other.index_type
+            and self.udf_func == other.udf_func
         )
 
     def __hash__(self) -> int:
@@ -1153,5 +1148,111 @@ class LogicalCreateIndex(Operator):
                 self.table_ref,
                 tuple(self.col_list),
                 self.index_type,
+                self.udf_func,
+            )
+        )
+
+
+class LogicalApplyAndMerge(Operator):
+    """Evaluate the function expression on the input data and return the merged output.
+    This operator simplifies the process of evaluating functions on a table source.
+    Currently, it performs an inner join while merging the function output with the
+    input data. This means that if the function does not return any output for a given
+    input row, that row will be dropped from the output. We can consider expanding this
+    to support left joins and other types of joins in the future.
+    """
+
+    def __init__(
+        self,
+        func_expr: FunctionExpression,
+        alias: Alias,
+        do_unnest: bool = False,
+        children: List = None,
+    ):
+        super().__init__(OperatorType.LOGICAL_APPLY_AND_MERGE, children)
+        self._func_expr = func_expr
+        self._do_unnest = do_unnest
+        self._alias = alias
+        self._merge_type = JoinType.INNER_JOIN
+
+    @property
+    def alias(self):
+        return self._alias
+
+    @property
+    def func_expr(self):
+        return self._func_expr
+
+    @property
+    def do_unnest(self):
+        return self._do_unnest
+
+    def __eq__(self, other):
+        is_subtree_equal = super().__eq__(other)
+        if not isinstance(other, LogicalApplyAndMerge):
+            return False
+        return (
+            is_subtree_equal
+            and self.func_expr == other.func_expr
+            and self.do_unnest == other.do_unnest
+            and self.alias == other.alias
+            and self._merge_type == other._merge_type
+        )
+
+    def __hash__(self) -> int:
+        return hash(
+            (
+                super().__hash__(),
+                self.func_expr,
+                self.do_unnest,
+                self.alias,
+                self._merge_type,
+            )
+        )
+
+
+class LogicalFaissIndexScan(Operator):
+    def __init__(
+        self,
+        index_name: str,
+        limit_count: ConstantValueExpression,
+        search_query_expr: FunctionExpression,
+        children: List = None,
+    ):
+        super().__init__(OperatorType.LOGICALFAISSINDEXSCAN, children)
+        self._index_name = index_name
+        self._limit_count = limit_count
+        self._search_query_expr = search_query_expr
+
+    @property
+    def index_name(self):
+        return self._index_name
+
+    @property
+    def limit_count(self):
+        return self._limit_count
+
+    @property
+    def search_query_expr(self):
+        return self._search_query_expr
+
+    def __eq__(self, other):
+        is_subtree_equal = super().__eq__(other)
+        if not isinstance(other, LogicalFaissIndexScan):
+            return False
+        return (
+            is_subtree_equal
+            and self.index_name == other.index_name
+            and self.limit_count == other.limit_count
+            and self.search_query_expr == other.search_query_expr
+        )
+
+    def __hash__(self) -> int:
+        return hash(
+            (
+                super().__hash__(),
+                self.index_name,
+                self.limit_count,
+                self.search_query_expr,
             )
         )
