@@ -59,7 +59,6 @@ from eva.utils.logging_manager import logger
 class StatementToPlanConvertor:
     def __init__(self):
         self._plan = None
-        self._dataset = None
 
     def visit_table_ref(self, table_ref: TableRef):
         """Bind table ref object and convert to LogicalGet, LogicalJoin,
@@ -70,8 +69,8 @@ class StatementToPlanConvertor:
         """
         if table_ref.is_table_atom():
             # Table
-            catalog_vid_metadata = table_ref.table.table_obj
-            self._plan = LogicalGet(table_ref, catalog_vid_metadata, table_ref.alias)
+            catalog_entry = table_ref.table.table_obj
+            self._plan = LogicalGet(table_ref, catalog_entry, table_ref.alias)
 
         elif table_ref.is_table_valued_expr():
             tve = table_ref.table_valued_expr
@@ -130,18 +129,18 @@ class StatementToPlanConvertor:
         if statement.groupby_clause is not None:
             self._visit_groupby(statement.groupby_clause)
 
-        # Projection operator
-        select_columns = statement.target_list
-
-        if select_columns is not None:
-            self._visit_projection(select_columns)
-
         if statement.orderby_list is not None:
             self._visit_orderby(statement.orderby_list)
 
         if statement.limit_count is not None:
             self._visit_limit(statement.limit_count)
 
+        # Projection operator
+        select_columns = statement.target_list
+
+        if select_columns is not None:
+            self._visit_projection(select_columns)
+
     def _visit_sample(self, sample_freq):
         sample_opr = LogicalSample(sample_freq)
         sample_opr.append_child(self._plan)
@@ -314,6 +313,7 @@ class StatementToPlanConvertor:
             statement.table_ref,
             statement.col_list,
             statement.index_type,
+            statement.udf_func,
         )
         self._plan = create_index_opr
 
