@@ -12,7 +12,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import List
+from typing import List, Tuple
 
 from eva.catalog.catalog_type import ColumnType, NdArrayType
 from eva.parser.statement import AbstractStatement
@@ -47,13 +47,13 @@ class ColumnDefinition:
         col_name: str,
         col_type: ColumnType,
         col_array_type: NdArrayType,
-        col_dim: List[int],
+        col_dim: Tuple[int],
         cci: ColConstraintInfo = ColConstraintInfo(),
     ):
         self._name = col_name
         self._type = col_type
         self._array_type = col_array_type
-        self._dimension = col_dim or []
+        self._dimension = col_dim or ()
         self._cci = cci
 
     @property
@@ -77,9 +77,20 @@ class ColumnDefinition:
         return self._cci
 
     def __str__(self):
-        return "{} {} {} {}".format(
-            self._name, self._type, self.array_type, self._dimension
-        )
+        dimension_str = ""
+        if self._dimension is not None:
+            dimension_str += "["
+            for dim in self._dimension:
+                dimension_str += str(dim) + ", "
+            dimension_str = dimension_str.rstrip(", ")
+            dimension_str += "]"
+
+        if self.array_type is None:
+            return "{} {}".format(self._name, self._type)
+        else:
+            return "{} {} {} {}".format(
+                self._name, self._type, self.array_type, dimension_str
+            )
 
     def __eq__(self, other):
         if not isinstance(other, ColumnDefinition):
@@ -94,9 +105,7 @@ class ColumnDefinition:
         )
 
     def __hash__(self) -> int:
-        return hash(
-            (self.name, self.type, self.array_type, tuple(self.dimension), self.cci)
-        )
+        return hash((self.name, self.type, self.array_type, self.dimension, self.cci))
 
 
 class CreateTableStatement(AbstractStatement):
@@ -119,7 +128,13 @@ class CreateTableStatement(AbstractStatement):
         self._column_list = column_list
 
     def __str__(self) -> str:
-        print_str = "CREATE TABLE {} ({})".format(self._table_info, self._if_not_exists)
+        print_str = "CREATE TABLE {} ({}) \n".format(
+            self._table_info, self._if_not_exists
+        )
+
+        for column in self.column_list:
+            print_str += str(column) + "\n"
+
         return print_str
 
     @property
@@ -149,6 +164,6 @@ class CreateTableStatement(AbstractStatement):
                 super().__hash__(),
                 self.table_info,
                 self.if_not_exists,
-                tuple(self.column_list),
+                tuple(self.column_list or []),
             )
         )
