@@ -44,10 +44,25 @@ class LoadDataStatement(AbstractStatement):
         self._file_options = file_options
 
     def __str__(self) -> str:
-        print_str = "LOAD {} INTO {}({}) WITH {}".format(
-            self._path.name, self._table_info, self._column_list, self._file_options
-        )
-        return print_str
+        file_option_str = ""
+        for key, value in self._file_options.items():
+            file_option_str += f"{str(key)}: {str(value)}"
+
+        column_list_str = ""
+        if self._column_list is not None:
+            for col in self._column_list:
+                column_list_str += str(col) + ", "
+            column_list_str = column_list_str.rstrip(", ")
+
+        if self._column_list is None:
+            load_stmt_str = "LOAD {} INTO {} WITH {}".format(
+                self._path.name, self._table_info, file_option_str
+            )
+        else:
+            load_stmt_str = "LOAD {} INTO {} ({}) WITH {}".format(
+                self._path.name, self._table_info, column_list_str, file_option_str
+            )
+        return load_stmt_str
 
     @property
     def table_info(self) -> TableInfo:
@@ -85,7 +100,7 @@ class LoadDataStatement(AbstractStatement):
                 super().__hash__(),
                 self.table_info,
                 self.path,
-                tuple(self.column_list),
+                tuple(self.column_list or []),
                 frozenset(self.file_options.items()),
             )
         )
