@@ -45,4 +45,6 @@ class PlanOprType(Enum):
     DROP_UDF = auto()
     EXPLAIN = auto()
     CREATE_INDEX = auto()
+    APPLY_AND_MERGE = auto()
+    FAISS_INDEX_SCAN = auto()
     # add other types
