@@ -16,7 +16,7 @@ import unittest
 from test.util import create_sample_csv, file_remove
 
 import pandas as pd
-from mock import MagicMock, call, patch
+from mock import MagicMock, patch
 
 from eva.executor.executor_utils import ExecutorError
 from eva.executor.load_executor import LoadDataExecutor
@@ -44,7 +44,7 @@ class LoadExecutorTest(unittest.TestCase):
         return plan
 
     @patch(
-        "eva.catalog.catalog_manager.CatalogManager.get_dataset_metadata",
+        "eva.catalog.catalog_manager.CatalogManager.get_table_catalog_entry",
         return_value=None,
     )
     def test_should_fail_to_find_table(self, catalog_mock):
@@ -67,13 +67,11 @@ class LoadExecutorTest(unittest.TestCase):
         with self.assertRaises(ExecutorError):
             next(load_executor.exec())
 
-    @patch("eva.catalog.catalog_manager.CatalogManager.get_dataset_metadata")
+    @patch("eva.catalog.catalog_manager.CatalogManager.get_table_catalog_entry")
     @patch("eva.executor.load_multimedia_executor.StorageEngine.factory")
     def test_should_call_csv_reader_and_storage_engine(
         self, factory_mock, catalog_mock
     ):
-        batch_frames = [list(range(5))] * 2
-
         # creates a dummy.csv
         create_sample_csv()
 
@@ -83,9 +81,9 @@ class LoadExecutorTest(unittest.TestCase):
         file_options = {}
         file_options["file_format"] = FileFormatType.CSV
         column_list = [
-            type("DataFrameColumn", (), {"name": "id"}),
-            type("DataFrameColumn", (), {"name": "frame_id"}),
-            type("DataFrameColumn", (), {"name": "video_id"}),
+            type("ColumnCatalogEntry", (), {"name": "id"}),
+            type("ColumnCatalogEntry", (), {"name": "frame_id"}),
+            type("ColumnCatalogEntry", (), {"name": "video_id"}),
         ]
         table_obj = MagicMock(columns=column_list)
         catalog_mock.return_value = table_obj
@@ -103,11 +101,8 @@ class LoadExecutorTest(unittest.TestCase):
 
         load_executor = LoadDataExecutor(plan)
         batch = next(load_executor.exec())
-        catalog_mock.assert_called_once_with(None, "dummy")
-        factory_mock.return_value.write.has_calls(
-            call(table_obj, batch_frames[0]),
-            call(table_obj, batch_frames[1]),
-        )
+        catalog_mock.assert_called_once_with("dummy", None)
+        self.assertEqual(factory_mock.return_value.write.call_args.args[0], table_obj)
 
         # Note: We call exec() from the child classes.
         self.assertEqual(
