@@ -14,14 +14,18 @@
 # limitations under the License.
 import unittest
 
+import pandas as pd
+
 from eva.expression.abstract_expression import ExpressionType
 from eva.expression.arithmetic_expression import ArithmeticExpression
 from eva.expression.constant_value_expression import ConstantValueExpression
+from eva.models.storage.batch import Batch
 
 
 class ArithmeticExpressionsTest(unittest.TestCase):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+        self.batch = Batch(pd.DataFrame([None]))
 
     def test_addition(self):
         const_exp1 = ConstantValueExpression(2)
@@ -31,7 +35,7 @@ class ArithmeticExpressionsTest(unittest.TestCase):
             ExpressionType.ARITHMETIC_ADD, const_exp1, const_exp2
         )
 
-        self.assertEqual([7], cmpr_exp.evaluate(None).frames[0].tolist())
+        self.assertEqual([7], cmpr_exp.evaluate(self.batch).frames[0].tolist())
 
     def test_subtraction(self):
         const_exp1 = ConstantValueExpression(5)
@@ -41,7 +45,7 @@ class ArithmeticExpressionsTest(unittest.TestCase):
             ExpressionType.ARITHMETIC_SUBTRACT, const_exp1, const_exp2
         )
 
-        self.assertEqual([3], cmpr_exp.evaluate(None).frames[0].tolist())
+        self.assertEqual([3], cmpr_exp.evaluate(self.batch).frames[0].tolist())
 
     def test_multiply(self):
         const_exp1 = ConstantValueExpression(3)
@@ -51,7 +55,7 @@ class ArithmeticExpressionsTest(unittest.TestCase):
             ExpressionType.ARITHMETIC_MULTIPLY, const_exp1, const_exp2
         )
 
-        self.assertEqual([15], cmpr_exp.evaluate(None).frames[0].tolist())
+        self.assertEqual([15], cmpr_exp.evaluate(self.batch).frames[0].tolist())
 
     def test_divide(self):
         const_exp1 = ConstantValueExpression(5)
@@ -61,7 +65,7 @@ class ArithmeticExpressionsTest(unittest.TestCase):
             ExpressionType.ARITHMETIC_DIVIDE, const_exp1, const_exp2
         )
 
-        self.assertEqual([1], cmpr_exp.evaluate(None).frames[0].tolist())
+        self.assertEqual([1], cmpr_exp.evaluate(self.batch).frames[0].tolist())
 
     def test_aaequality(self):
         const_exp1 = ConstantValueExpression(5)
