@@ -16,6 +16,9 @@ import unittest
 from test.util import create_sample_video, create_table, file_remove, load_inbuilt_udfs
 
 from eva.catalog.catalog_manager import CatalogManager
+from eva.optimizer.plan_generator import PlanGenerator
+from eva.optimizer.rules.rules import XformLateralJoinToLinearFlow
+from eva.optimizer.rules.rules_manager import disable_rules
 from eva.server.command_handler import execute_query_fetch_all
 
 NUM_FRAMES = 10
@@ -50,7 +53,11 @@ class ExplainExecutorTest(unittest.TestCase):
         expected_output = """|__ SeqScanPlan\n    |__ StoragePlan\n"""
         self.assertEqual(batch.frames[0][0], expected_output)
 
-        select_query = "EXPLAIN SELECT id, data FROM MyVideo JOIN LATERAL DummyObjectDetector(data) AS T ;"
-        batch = execute_query_fetch_all(select_query)
-        expected_output = """|__ ProjectPlan\n    |__ LateralJoinPlan\n        |__ SeqScanPlan\n            |__ StoragePlan\n        |__ FunctionScanPlan\n"""
-        self.assertEqual(batch.frames[0][0], expected_output)
+        with disable_rules([XformLateralJoinToLinearFlow()]) as rules_manager:
+            custom_plan_generator = PlanGenerator(rules_manager)
+            select_query = "EXPLAIN SELECT id, data FROM MyVideo JOIN LATERAL DummyObjectDetector(data) AS T ;"
+            batch = execute_query_fetch_all(
+                select_query, plan_generator=custom_plan_generator
+            )
+            expected_output = """|__ ProjectPlan\n    |__ LateralJoinPlan\n        |__ SeqScanPlan\n            |__ StoragePlan\n        |__ FunctionScanPlan\n"""
+            self.assertEqual(batch.frames[0][0], expected_output)
