@@ -19,6 +19,7 @@ from test.util import (
     create_sample_video,
     create_table,
     file_remove,
+    get_logical_query_plan,
     load_inbuilt_udfs,
 )
 
@@ -28,6 +29,7 @@ import pytest
 
 from eva.binder.binder_utils import BinderError
 from eva.catalog.catalog_manager import CatalogManager
+from eva.configuration.constants import EVA_ROOT_DIR
 from eva.models.storage.batch import Batch
 from eva.readers.opencv_reader import OpenCVReader
 from eva.server.command_handler import execute_query_fetch_all
@@ -42,6 +44,9 @@ class SelectExecutorTest(unittest.TestCase):
         video_file_path = create_sample_video(NUM_FRAMES)
         load_query = f"LOAD VIDEO '{video_file_path}' INTO MyVideo;"
         execute_query_fetch_all(load_query)
+        ua_detrac = f"{EVA_ROOT_DIR}/data/ua_detrac/ua_detrac.mp4"
+        load_query = f"LOAD VIDEO '{ua_detrac}' INTO DETRAC;"
+        execute_query_fetch_all(load_query)
         load_inbuilt_udfs()
         cls.table1 = create_table("table1", 100, 3)
         cls.table2 = create_table("table2", 500, 3)
@@ -100,7 +105,7 @@ class SelectExecutorTest(unittest.TestCase):
         expected_batch = Batch(frames=pd.DataFrame(expected_rows))
         self.assertEqual(actual_batch, expected_batch)
 
-        select_query = "SELECT name, id,data FROM MyVideo;"
+        select_query = "SELECT * FROM MyVideo;"
         actual_batch = execute_query_fetch_all(select_query)
         actual_batch.sort()
         expected_batch = list(create_dummy_batches())
@@ -136,7 +141,7 @@ class SelectExecutorTest(unittest.TestCase):
     @unittest.skip("Not supported in current version")
     def test_select_star_in_lateral_join(self):
         select_query = """SELECT * FROM MyVideo JOIN LATERAL
-                          FastRCNNObjectDetector(data);"""
+                          YoloV5(data);"""
         actual_batch = execute_query_fetch_all(select_query)
         self.assertEqual(actual_batch.frames.columns, ["myvideo.id"])
 
@@ -158,7 +163,7 @@ class SelectExecutorTest(unittest.TestCase):
         self.assertEqual(actual_batch, expected_batch)
 
     def test_select_and_where_video_in_table(self):
-        select_query = "SELECT name, id,data FROM MyVideo WHERE id = 5;"
+        select_query = "SELECT * FROM MyVideo WHERE id = 5;"
         actual_batch = execute_query_fetch_all(select_query)
         expected_batch = list(create_dummy_batches(filters=[5]))[0]
         self.assertEqual(actual_batch, expected_batch)
@@ -184,7 +189,7 @@ class SelectExecutorTest(unittest.TestCase):
             expected_batch.project(["myvideo.id", "myvideo.data"]),
         )
 
-        select_query = "SELECT name, id, data FROM MyVideo WHERE id >= 2 AND id < 5;"
+        select_query = "SELECT * FROM MyVideo WHERE id >= 2 AND id < 5;"
         actual_batch = execute_query_fetch_all(select_query)
         actual_batch.sort()
         expected_batch = list(create_dummy_batches(filters=range(2, 5)))[0]
@@ -192,8 +197,8 @@ class SelectExecutorTest(unittest.TestCase):
         self.assertEqual(actual_batch, expected_batch)
 
     def test_nested_select_video_in_table(self):
-        nested_select_query = """SELECT name, id, data FROM
-            (SELECT name, id, data FROM MyVideo WHERE id >= 2 AND id < 5) AS T
+        nested_select_query = """SELECT * FROM
+            (SELECT * FROM MyVideo WHERE id >= 2 AND id < 5) AS T
             WHERE id >= 3;"""
         actual_batch = execute_query_fetch_all(nested_select_query)
         actual_batch.sort()
@@ -201,8 +206,8 @@ class SelectExecutorTest(unittest.TestCase):
         expected_batch.modify_column_alias("T")
         self.assertEqual(actual_batch, expected_batch)
 
-        nested_select_query = """SELECT T.name, T.id, T.data FROM
-            (SELECT name, id, data FROM MyVideo WHERE id >= 2 AND id < 5) AS T
+        nested_select_query = """SELECT * FROM
+            (SELECT * FROM MyVideo WHERE id >= 2 AND id < 5) AS T
             WHERE id >= 3;"""
         actual_batch = execute_query_fetch_all(nested_select_query)
         actual_batch.sort("T.id")
@@ -211,8 +216,8 @@ class SelectExecutorTest(unittest.TestCase):
         self.assertEqual(actual_batch, expected_batch)
 
     def test_select_and_union_video_in_table(self):
-        select_query = """SELECT name, id, data FROM MyVideo WHERE id < 3
-            UNION ALL SELECT name, id, data FROM MyVideo WHERE id > 7;"""
+        select_query = """SELECT * FROM MyVideo WHERE id < 3
+            UNION ALL SELECT * FROM MyVideo WHERE id > 7;"""
         actual_batch = execute_query_fetch_all(select_query)
         actual_batch.sort("myvideo.id")
         expected_batch = list(
@@ -222,9 +227,9 @@ class SelectExecutorTest(unittest.TestCase):
         )[0]
         self.assertEqual(actual_batch, expected_batch)
 
-        select_query = """SELECT name, id, data FROM MyVideo WHERE id < 2
-            UNION ALL SELECT name, id, data FROM MyVideo WHERE id > 4 AND id < 6
-            UNION ALL SELECT name, id, data FROM MyVideo WHERE id > 7;"""
+        select_query = """SELECT * FROM MyVideo WHERE id < 2
+            UNION ALL SELECT * FROM MyVideo WHERE id > 4 AND id < 6
+            UNION ALL SELECT * FROM MyVideo WHERE id > 7;"""
         actual_batch = execute_query_fetch_all(select_query)
         actual_batch.sort("myvideo.id")
         expected_batch = list(
@@ -235,7 +240,7 @@ class SelectExecutorTest(unittest.TestCase):
         self.assertEqual(actual_batch, expected_batch)
 
     def test_select_and_limit(self):
-        select_query = "SELECT name,id,data FROM MyVideo ORDER BY id LIMIT 5;"
+        select_query = "SELECT * FROM MyVideo ORDER BY id LIMIT 5;"
         actual_batch = execute_query_fetch_all(select_query)
         actual_batch.sort()
         expected_batch = list(create_dummy_batches(num_frames=10, batch_size=5))
@@ -243,19 +248,25 @@ class SelectExecutorTest(unittest.TestCase):
         self.assertEqual(len(actual_batch), len(expected_batch[0]))
         self.assertEqual(actual_batch, expected_batch[0])
 
+    def test_select_and_aggregate(self):
+        simple_aggregate_query = "SELECT COUNT(*), AVG(id) FROM MyVideo;"
+        actual_batch = execute_query_fetch_all(simple_aggregate_query)
+
+        self.assertEqual(actual_batch.frames.iat[0, 0], 10)
+        self.assertEqual(actual_batch.frames.iat[0, 1], 4.5)
+
     def test_select_and_sample(self):
-        select_query = "SELECT name, id,data FROM MyVideo SAMPLE 7 ORDER BY id;"
+        select_query = "SELECT id FROM MyVideo SAMPLE 7 ORDER BY id;"
         actual_batch = execute_query_fetch_all(select_query)
         actual_batch.sort()
 
         expected_batch = list(create_dummy_batches(filters=range(0, NUM_FRAMES, 7)))
+        expected_batch[0] = expected_batch[0].project(["myvideo.id"])
 
         self.assertEqual(len(actual_batch), len(expected_batch[0]))
-        # Since frames are fetched in random order, this test might be flaky
-        # Disabling it for time being
         self.assertEqual(actual_batch, expected_batch[0])
 
-    def test_select_and_groupby(self):
+    def test_select_and_groupby_first(self):
         # groupby and orderby together not tested because groupby
         # only applies to video data which is already sorted
         segment_size = 3
@@ -271,9 +282,13 @@ class SelectExecutorTest(unittest.TestCase):
         segments = [i for i in segments if len(i) == segment_size]
         expected_batch = list(create_dummy_4d_batches(filters=segments))[0]
         self.assertEqual(len(actual_batch), len(expected_batch))
+
+        expected_batch.rename(
+            columns={"myvideo.id": "FIRST.id", "myvideo.data": "SEGMENT.data"}
+        )
         self.assertEqual(
             actual_batch,
-            expected_batch.project(["myvideo.id", "myvideo.data"]),
+            expected_batch.project(["FIRST.id", "SEGMENT.data"]),
         )
 
     def test_select_and_groupby_with_last(self):
@@ -294,9 +309,13 @@ class SelectExecutorTest(unittest.TestCase):
             create_dummy_4d_batches(filters=segments, start_id=segment_size - 1)
         )[0]
         self.assertEqual(len(actual_batch), len(expected_batch))
+
+        expected_batch.rename(
+            columns={"myvideo.id": "LAST.id", "myvideo.data": "SEGMENT.data"}
+        )
         self.assertEqual(
             actual_batch,
-            expected_batch.project(["myvideo.id", "myvideo.data"]),
+            expected_batch.project(["LAST.id", "SEGMENT.data"]),
         )
 
     def test_select_and_groupby_should_fail_with_incorrect_pattern(self):
@@ -340,47 +359,48 @@ class SelectExecutorTest(unittest.TestCase):
         segments = [i for i in segments if len(i) == segment_size]
         expected_batch = list(create_dummy_4d_batches(filters=segments))[0]
         self.assertEqual(len(actual_batch), len(expected_batch))
+
+        expected_batch.rename(
+            columns={"myvideo.id": "FIRST.id", "myvideo.data": "SEGMENT.data"}
+        )
+
         self.assertEqual(
             actual_batch,
-            expected_batch.project(["myvideo.id", "myvideo.data"]),
+            expected_batch.project(["FIRST.id", "SEGMENT.data"]),
         )
 
     def test_select_and_sample_with_predicate(self):
-        select_query = (
-            "SELECT name, id,data FROM MyVideo SAMPLE 2 WHERE id > 5 ORDER BY id;"
-        )
+        select_query = "SELECT id FROM MyVideo SAMPLE 2 WHERE id > 5 ORDER BY id;"
         actual_batch = execute_query_fetch_all(select_query)
         expected_batch = list(create_dummy_batches(filters=range(6, NUM_FRAMES, 2)))
-        self.assertEqual(actual_batch, expected_batch[0])
+        self.assertEqual(actual_batch, expected_batch[0].project(["myvideo.id"]))
+
+        select_query = "SELECT id FROM MyVideo SAMPLE 4 WHERE id > 2 ORDER BY id;"
+        actual_batch = execute_query_fetch_all(select_query)
+        expected_batch = list(create_dummy_batches(filters=range(4, NUM_FRAMES, 4)))
+        self.assertEqual(actual_batch, expected_batch[0].project(["myvideo.id"]))
 
         select_query = (
-            "SELECT name, id,data FROM MyVideo SAMPLE 4 WHERE id > 2 ORDER BY id;"
+            "SELECT id FROM MyVideo SAMPLE 2 WHERE id > 2 AND id < 8 ORDER BY id;"
         )
         actual_batch = execute_query_fetch_all(select_query)
-        print(actual_batch)
-        expected_batch = list(create_dummy_batches(filters=range(4, NUM_FRAMES, 4)))
-        self.assertEqual(actual_batch, expected_batch[0])
-
-        select_query = "SELECT name, id,data FROM MyVideo SAMPLE 2 WHERE id > 2 AND id < 8 ORDER BY id;"
-        actual_batch = execute_query_fetch_all(select_query)
-        print(actual_batch)
         expected_batch = list(create_dummy_batches(filters=range(4, 8, 2)))
-        self.assertEqual(actual_batch, expected_batch[0])
+        self.assertEqual(actual_batch, expected_batch[0].project(["myvideo.id"]))
 
     @pytest.mark.torchtest
     def test_lateral_join(self):
-        select_query = """SELECT id, a FROM MyVideo JOIN LATERAL
-                        FastRCNNObjectDetector(data) AS T(a,b,c) WHERE id < 5;"""
+        select_query = """SELECT id, a FROM DETRAC JOIN LATERAL
+                        YoloV5(data) AS T(a,b,c) WHERE id < 5;"""
         actual_batch = execute_query_fetch_all(select_query)
-        self.assertEqual(list(actual_batch.columns), ["myvideo.id", "T.a"])
+        self.assertEqual(list(actual_batch.columns), ["detrac.id", "T.a"])
         self.assertEqual(len(actual_batch), 5)
 
     @pytest.mark.torchtest
     def test_lateral_join_with_multiple_projects(self):
-        select_query = """SELECT id, T.labels FROM MyVideo JOIN LATERAL
-                        FastRCNNObjectDetector(data) AS T WHERE id < 5;"""
+        select_query = """SELECT id, T.labels FROM DETRAC JOIN LATERAL
+                        YoloV5(data) AS T WHERE id < 5;"""
         actual_batch = execute_query_fetch_all(select_query)
-        self.assertTrue(all(actual_batch.frames.columns == ["myvideo.id", "T.labels"]))
+        self.assertTrue(all(actual_batch.frames.columns == ["detrac.id", "T.labels"]))
         self.assertEqual(len(actual_batch), 5)
 
     def test_lateral_join_with_unnest(self):
@@ -392,7 +412,7 @@ class SelectExecutorTest(unittest.TestCase):
         expected = Batch(
             pd.DataFrame(
                 {
-                    "myvideo.id": np.array([0, 1]),
+                    "myvideo.id": np.array([0, 1], dtype=np.intp),
                     "T.label": np.array(["person", "bicycle"]),
                 }
             )
@@ -408,7 +428,7 @@ class SelectExecutorTest(unittest.TestCase):
         expected = Batch(
             pd.DataFrame(
                 {
-                    "myvideo.id": np.array([0, 1]),
+                    "myvideo.id": np.array([0, 1], dtype=np.intp),
                     "T.label": np.array(["person", "bicycle"]),
                 }
             )
@@ -425,7 +445,9 @@ class SelectExecutorTest(unittest.TestCase):
         expected = Batch(
             pd.DataFrame(
                 {
-                    "myvideo.id": np.array([0, 0, 2, 2, 4, 4, 6, 6, 8, 8]),
+                    "myvideo.id": np.array(
+                        [0, 0, 2, 2, 4, 4, 6, 6, 8, 8], dtype=np.intp
+                    ),
                     "T.label": np.array(
                         [
                             "person",
@@ -455,12 +477,11 @@ class SelectExecutorTest(unittest.TestCase):
         expected = Batch(
             pd.DataFrame(
                 {
-                    "myvideo.id": np.array([0, 0, 1, 1]),
+                    "myvideo.id": np.array([0, 0, 1, 1], np.intp),
                     "T.label": np.array(["person", "person", "bicycle", "bicycle"]),
                 }
             )
         )
-
         self.assertEqual(unnest_batch, expected)
 
     def test_should_raise_error_with_missing_alias_in_lateral_join(self):
@@ -577,3 +598,10 @@ class SelectExecutorTest(unittest.TestCase):
                 expected_batch.sort_orderby(["table1.a0"]),
                 actual_batch.sort_orderby(["table1.a0"]),
             )
+
+    def test_expression_tree_signature(self):
+        plan = get_logical_query_plan(
+            "SELECT DummyMultiObjectDetector(data).labels FROM MyVideo"
+        )
+        signature = plan.target_list[0].signature()
+        self.assertEqual(signature, "DummyMultiObjectDetector(MyVideo.data)")
