@@ -69,6 +69,31 @@ class ParserTests(unittest.TestCase):
         actual_stmt = eva_stmt_list[0]
         self.assertEqual(actual_stmt, expected_stmt)
 
+        # create index on UDF expression
+        create_index_query = (
+            "CREATE INDEX testindex ON MyVideo (FeatureExtractor(featCol)) USING HNSW;"
+        )
+        eva_stmt_list = parser.parse(create_index_query)
+
+        # check stmt itself
+        self.assertIsInstance(eva_stmt_list, list)
+        self.assertEqual(len(eva_stmt_list), 1)
+        self.assertEqual(eva_stmt_list[0].stmt_type, StatementType.CREATE_INDEX)
+
+        func_expr = FunctionExpression(None, "FeatureExtractor")
+        func_expr.append_child(TupleValueExpression("featCol"))
+        expected_stmt = CreateIndexStatement(
+            "testindex",
+            TableRef(TableInfo("MyVideo")),
+            [
+                ColumnDefinition("featCol", None, None, None),
+            ],
+            IndexType.HNSW,
+            func_expr,
+        )
+        actual_stmt = eva_stmt_list[0]
+        self.assertEqual(actual_stmt, expected_stmt)
+
     @unittest.skip("Skip parser exception handling testcase, moved to binder")
     def test_create_index_exception_statement(self):
         parser = Parser()
@@ -103,7 +128,7 @@ class ParserTests(unittest.TestCase):
     def test_explain_ddl_statement(self):
         parser = Parser()
 
-        select_query = """SELECT id, FastRCNNObjectDetector(frame).labels FROM MyVideo
+        select_query = """SELECT id, YoloV5(frame).labels FROM MyVideo
                         WHERE id<5; """
         explain_query = "EXPLAIN CREATE MATERIALIZED VIEW uadtrac_fastRCNN (id, labels) AS {}".format(
             select_query
@@ -125,7 +150,7 @@ class ParserTests(unittest.TestCase):
             inner_stmt.view_info, TableRef(TableInfo("uadetrac_fastRCNN"))
         )
 
-    def test_create_statement(self):
+    def test_create_table_statement(self):
         parser = Parser()
 
         single_queries = []
@@ -147,33 +172,39 @@ class ParserTests(unittest.TestCase):
             TableInfo("Persons"),
             True,
             [
-                ColumnDefinition("Frame_ID", ColumnType.INTEGER, None, [], unique_cci),
+                ColumnDefinition("Frame_ID", ColumnType.INTEGER, None, (), unique_cci),
                 ColumnDefinition(
-                    "Frame_Data", ColumnType.TEXT, None, [10], expected_cci
+                    "Frame_Data", ColumnType.TEXT, None, (10,), expected_cci
                 ),
                 ColumnDefinition(
-                    "Frame_Value", ColumnType.FLOAT, None, [1000, 201], expected_cci
+                    "Frame_Value", ColumnType.FLOAT, None, (1000, 201), expected_cci
                 ),
                 ColumnDefinition(
                     "Frame_Array",
                     ColumnType.NDARRAY,
                     NdArrayType.UINT8,
-                    [5, 100, 2432, 4324, 100],
+                    (5, 100, 2432, 4324, 100),
                     expected_cci,
                 ),
             ],
         )
-        expected_stmt_str = "CREATE TABLE Persons (True)"
 
         for query in single_queries:
             eva_statement_list = parser.parse(query)
             self.assertIsInstance(eva_statement_list, list)
             self.assertEqual(len(eva_statement_list), 1)
             self.assertIsInstance(eva_statement_list[0], AbstractStatement)
-            self.assertEqual(str(eva_statement_list[0]), expected_stmt_str)
             self.assertEqual(eva_statement_list[0], expected_stmt)
 
-    def test_rename_statement(self):
+    def test_create_table_exception_statement(self):
+        parser = Parser()
+
+        create_table_query = "CREATE TABLE ();"
+
+        with self.assertRaises(Exception):
+            parser.parse(create_table_query)
+
+    def test_rename_table_statement(self):
         parser = Parser()
         rename_queries = "RENAME TABLE student TO student_info"
         expected_stmt = RenameTableStatement(
@@ -250,7 +281,7 @@ class ParserTests(unittest.TestCase):
         multiple_queries = []
         multiple_queries.append(
             "SELECT CLASS FROM TAIPAI \
-                WHERE CLASS = 'VAN' AND REDNESS < 300  OR REDNESS > 500; \
+                WHERE (CLASS = 'VAN' AND REDNESS < 300)  OR REDNESS > 500; \
                 SELECT REDNESS FROM TAIPAI \
                 WHERE (CLASS = 'VAN' AND REDNESS = 300)"
         )
@@ -288,6 +319,16 @@ class ParserTests(unittest.TestCase):
         self.assertIsNotNone(select_stmt.where_clause)
         # other tests should go in expression testing
 
+    def test_select_with_empty_string_literal(self):
+        parser = Parser()
+
+        select_query = """SELECT '' FROM TAIPAI;"""
+
+        eva_statement_list = parser.parse(select_query)
+        self.assertIsInstance(eva_statement_list, list)
+        self.assertEqual(len(eva_statement_list), 1)
+        self.assertEqual(eva_statement_list[0].stmt_type, StatementType.SELECT)
+
     def test_select_union_statement(self):
         parser = Parser()
         select_union_query = "SELECT CLASS, REDNESS FROM TAIPAI \
@@ -353,12 +394,6 @@ class ParserTests(unittest.TestCase):
             ConstantValueExpression("8f", v_type=ColumnType.TEXT),
         )
 
-    def test_select_statement_groupby_class_with_multiple_attributes_should_raise(self):
-        # GROUP BY with multiple attributes should raise Syntax Error
-        parser = Parser()
-        select_query = "SELECT FIRST(id) FROM TAIPAI GROUP BY '8f', '12f';"
-        self.assertRaises(SyntaxError, parser.parse, select_query)
-
     def test_select_statement_orderby_class(self):
         """Testing order by clause in select statement
         Class: SelectStatement"""
@@ -525,16 +560,16 @@ class ParserTests(unittest.TestCase):
                     "Frame_Array",
                     ColumnType.NDARRAY,
                     NdArrayType.UINT8,
-                    [3, 256, 256],
+                    (3, 256, 256),
                     expected_cci,
                 )
             ],
             [
                 ColumnDefinition(
-                    "Labels", ColumnType.NDARRAY, NdArrayType.STR, [10], expected_cci
+                    "Labels", ColumnType.NDARRAY, NdArrayType.STR, (10,), expected_cci
                 ),
                 ColumnDefinition(
-                    "Bbox", ColumnType.NDARRAY, NdArrayType.UINT8, [10, 4], expected_cci
+                    "Bbox", ColumnType.NDARRAY, NdArrayType.UINT8, (10, 4), expected_cci
                 ),
             ],
             Path("data/fastrcnn.py"),
@@ -699,10 +734,10 @@ class ParserTests(unittest.TestCase):
                     "frame",
                     ColumnType.NDARRAY,
                     NdArrayType.UINT8,
-                    [3, 256, 256],
+                    (3, 256, 256),
                 )
             ],
-            [ColumnDefinition("labels", ColumnType.NDARRAY, NdArrayType.STR, [10])],
+            [ColumnDefinition("labels", ColumnType.NDARRAY, NdArrayType.STR, (10))],
             Path("data/fastrcnn.py"),
             "Classification",
         )
@@ -713,7 +748,7 @@ class ParserTests(unittest.TestCase):
         self.assertNotEqual(select_stmt, create_udf)
 
     def test_materialized_view(self):
-        select_query = """SELECT id, FastRCNNObjectDetector(frame).labels FROM MyVideo
+        select_query = """SELECT id, YoloV5(frame).labels FROM MyVideo
                         WHERE id<5; """
         query = "CREATE MATERIALIZED VIEW uadtrac_fastRCNN (id, labels) AS {}".format(
             select_query
@@ -819,13 +854,6 @@ class ParserTests(unittest.TestCase):
         expected_stmt = SelectStatement(select_list, from_table, where_clause)
         self.assertEqual(select_stmt, expected_stmt)
 
-    def test_multiple_join_with_single_ON_should_raise(self):
-        select_query = """SELECT table1.a FROM table1 JOIN table2 JOIN table3
-                    ON table3.a = table1.a AND table1.a = table2.a;"""
-        parser = Parser()
-        with self.assertRaises(Exception):
-            parser.parse(select_query)[0]
-
     def test_lateral_join(self):
         select_query = """SELECT frame FROM MyVideo JOIN LATERAL
                             ObjectDet(frame) AS OD;"""
@@ -844,3 +872,14 @@ class ParserTests(unittest.TestCase):
         )
         expected_stmt = SelectStatement([tuple_frame], from_table)
         self.assertEqual(select_stmt, expected_stmt)
+
+    def test_lark(self):
+        query = """CREATE UDF FaceDetector
+                  INPUT  (frame NDARRAY UINT8(3, ANYDIM, ANYDIM))
+                  OUTPUT (bboxes NDARRAY FLOAT32(ANYDIM, 4),
+                          scores NDARRAY FLOAT32(ANYDIM))
+                  TYPE  FaceDetection
+                  IMPL  'eva/udfs/face_detector.py';
+                  """
+        parser = Parser()
+        parser.parse(query)
