@@ -16,10 +16,11 @@ import unittest
 from unittest.mock import MagicMock
 
 import mock
+import pytest
 
 from eva.catalog.catalog_type import ColumnType, NdArrayType, TableType
-from eva.catalog.models.df_column import DataFrameColumn
-from eva.catalog.models.df_metadata import DataFrameMetadata
+from eva.catalog.models.column_catalog import ColumnCatalogEntry
+from eva.catalog.models.table_catalog import TableCatalogEntry
 from eva.storage.storage_engine import StorageEngine
 
 
@@ -29,11 +30,11 @@ class VideoStorageEngineTest(unittest.TestCase):
         self.table = None
 
     def create_sample_table(self):
-        table_info = DataFrameMetadata(
+        table_info = TableCatalogEntry(
             "dataset", "dataset", table_type=TableType.VIDEO_DATA
         )
-        column_1 = DataFrameColumn("id", ColumnType.INTEGER, False)
-        column_2 = DataFrameColumn(
+        column_1 = ColumnCatalogEntry("id", ColumnType.INTEGER, False)
+        column_2 = ColumnCatalogEntry(
             "data", ColumnType.NDARRAY, False, NdArrayType.UINT8, [2, 2, 3]
         )
         table_info.schema = [column_1, column_2]
@@ -53,6 +54,7 @@ class VideoStorageEngineTest(unittest.TestCase):
         m.side_effect = FileExistsError
         with self.assertRaises(FileExistsError):
             self.video_engine.create(self.table, if_not_exists=False)
+        self.video_engine.create(self.table, if_not_exists=True)
 
     def test_write(self):
         batch = MagicMock()
@@ -61,3 +63,20 @@ class VideoStorageEngineTest(unittest.TestCase):
         table.file_url = Exception()
         with self.assertRaises(Exception):
             self.video_engine.write(table, batch)
+
+    def test_delete(self):
+        batch = MagicMock()
+        batch.frames = []
+        table = MagicMock()
+        table.file_url = Exception()
+        with self.assertRaises(Exception):
+            self.video_engine.delete(table, batch)
+
+    def test_rename(self):
+
+        table_info = TableCatalogEntry(
+            "new_name", "new_name", table_type=TableType.VIDEO_DATA
+        )
+
+        with pytest.raises(Exception):
+            self.video_engine.rename(self.table, table_info)
