@@ -28,7 +28,7 @@ class CMDClientTest(unittest.TestCase):
 
         with mock.patch.object(sys, "argv", ["test"]):
             main()
-        mock_client.called_once_with("0.0.0.0", 5432)
+        mock_client.assert_called_once_with(host="0.0.0.0", port=5432)
 
     def test_parse_args(self):
         from eva.eva_cmd_client import parse_args
